Learn R Programming

chromPlot (version 1.0.0)

hg_cytoBandIdeo: cytoBandIdeo human

Description

Describes the positions of cytogenetic bands with a chromosome of human.

Usage

data(hg_cytoBandIdeo)

Arguments

Value

data.frame that contain the positions of cytogenetic bands with a chromosome of human.

Format

A data frame with 862 observations on the following 5 variables.
Chrom
a character vector
Start
a numeric vector
End
a numeric vector
Name
a character vector
gieStain
a character vector

Details

This file describes the cytogenetics positions on chromosomes of human. specifically it has 5 columns Chrom, Start, End, Name y Group. Chrom referenced to the chromosomes, the Start and End columns indicated the start and end positions, while that Name indicated the name of cytogenetics Bands, finally, Group column contains informations associated to the Giemsa stain results.

Examples

Run this code
data(hg_cytoBandIdeo)
## maybe str(hg_cytoBandIdeo) ; plot(hg_cytoBandIdeo) ...

Run the code above in your browser using DataLab