Describes the positions of cytogenetic bands with a chromosome of mouse.
Usage
data(mm10_cytoBandIdeo)
Arguments
Value
data.frame that contain the positions of cytogenetic bands with a chromosome
of mouse.
Format
A data frame with 448 observations on the following 5 variables.
Chrom
a character vector
Start
a numeric vector
End
a numeric vector
Name
a character vector
gieStain
a character vector
Details
This file describes the cytogenetics positions on chromosomes of mouse.
specifically it has 5 columns Chrom, Start, End, Name y Group.
Chrom referenced to the chromosomes, the Start and End columns indicated
the start and end positions, while that Name indicated the name of
cytogenetics Bands, finally, Group column contains informations associated
to the Giemsa stain results.