chromPlot(annot1, annot2, annot3, annot4, stat, stat2,
scale.title="Counts", statTyp="p", scex=1, spty=20, statCol, statCol2,
statName="Statistic", statName2="Statistic2", bands, bandsDesc, gaps,
gapsDesc, segment, segmentDesc, segment2=NULL, segment2Desc=NULL, chr,
bin=1e6, yAxis=TRUE, figCols=NULL, colBand="lightgray", colAnnot1="brown",
colAnnot2="gold", colAnnot3="darkgreen", colAnnot4="blue", colSegments=c("darkgreen",
"orange", "blue", "darkslategray2", "cyan", "blueviolet", "goldenrod3", "darkseagreen4",
"red", "green", "salmon", "darkolivegreen", "maroon", "purple"),
colSegments2=colSegments[-1L], colStat="blue", colStat2="orange", title=NULL,
plotRndchr=FALSE, maxSegs=200, noHist=FALSE, segLwd=3, sortSegs=TRUE,
chrSide=c(-1, -1, -1, -1, 1, 1, -1, 1), cex=0.75, legChrom, org=NULL, strand=NULL,
stack=TRUE, statThreshold=NULL, statThreshold2=NULL, statSumm="none")If plotted on the same chromosomal side, tracks will be plotted on top of each other, in the order they are in the function's syntax. This can be used for plotting stacked barplots if, for instance, annot1, annot2, annot3, and annot4 are supersets of ecah other. This, however, is not enforced nor checked. An alternative way to create a stacked histogram is providing a single track with Group category. The user can modify the side tracks are plotted on by modifying chrSide.
The segment and segment2 tracks are plotted as vertical bars by default. However, the their elements exceed in number given to maxSegs or if the maximum segment size is smaller than bin, they are plotted as histograms. This behaviour can be modified by setting noHist = TRUE.
For more details and usage examples see the vignette.
data(hg_cytoBandIdeo)
data(hg_gap)
chromPlot(bands=hg_cytoBandIdeo, gaps=hg_gap)
Run the code above in your browser using DataLab